from __future__ import unicode_literals

import os
import logging

from mopidy import config, ext

logger = logging.getLogger(__name__)
__version__ = '0.1.8'


class Extension(ext.Extension):

    dist_name = 'Mopidy-GPIO'
    ext_name = 'gpio'
    version = __version__

    def get_default_config(self):
        conf_file = os.path.join(os.path.dirname(__file__), 'ext.conf')
        return config.read(conf_file)

    def get_config_schema(self):
        schema = super(Extension, self).get_config_schema()
        schema['pin_button_vol_up'] = config.Integer()
        schema['pin_button_vol_down'] = config.Integer()
        return schema

    def setup(self, registry):
		from .backend import GPIOBackend
        registry.add('backend', GPIOBackend)


from __future__ import unicode_literals

import unittest

# from mopidy_ttsgpio import frontend as frontend_lib
from mopidy_gpio import Extension


class ExtensionTest(unittest.TestCase):

    def test_get_default_config(self):
        ext = Extension()

        config = ext.get_default_config()

        self.assertIn('[gpio]', config)
        self.assertIn('enabled = true', config)

    def test_get_config_schema(self):
        ext = Extension()
        schema = ext.get_config_schema()
        self.assertIn('pin_button_main', schema)

        # TODO Test the content of your config schema
        # self.assertIn('username', schema)
        # self.assertIn('password', schema)

    # TODO Write more tests
